//
//  AMRollOverButton.h
//  PlateControl
//
//  Created by Andreas on Sat Jan 24 2004.
//  Copyright (c) 2004 Andreas Mayer. All rights reserved.
//
//	2005-06-02	- added shading support
//	2005-07-09	- added -tracksMouseInside and -setTracksMouseInside:
//					  (default is YES for compatibility reasons)
//	2008-04-29	- added controlShadow
//	2011-08-08	- appearance is now encapsulated inside AMRollOverBottonAppearance
//					  each subclass of AMRollOverButton has its own distinct appearance
//					  accessors are +appearance and +setAppearance:
//					- buttonType and bezelStyle are explicitely overwritten from NSButton
//	2012-08-06	- replaced accessor method declarations with property declarations


#import <AppKit/AppKit.h>
#import "AMRollOverButtonCell.h"
#import "AMRollOverButtonAppearance.h"


@interface AMRollOverButton : NSButton {
	NSButtonType am_buttonType; // there is no accessor for this in NSButton, so we keep track of the value here
	NSTrackingRectTag am_trackingRect;
	BOOL am_doesNotTrackMouseInside;
}

+ (AMRollOverButtonAppearance *)appearance;
+ (void)setAppearance:(AMRollOverButtonAppearance *)newAppearance;
+ (NSURL *)appearanceDataURL; // overwrite if you don't want to load the button data from the main bundle

- (id)initWithFrame:(NSRect)frameRect andTitle:(NSString *)title;

@property BOOL tracksMouseInside;
// in case you don't need the roll over effect, set this to NO

// the accessor methods invoke the equally named cell methods

@property NSControlSize controlSize;
@property (strong) NSColor *controlColor;
@property (strong) NSColor *shadingColor;
@property (strong) NSColor *frameColor;
@property (strong) NSColor *textColor;
@property (strong) NSColor *arrowColor;
@property (strong) NSColor *mouseoverControlColor;
@property (strong) NSColor *mouseoverShadingColor;
@property (strong) NSColor *mouseoverFrameColor;
@property (strong) NSColor *mouseoverTextColor;
@property (strong) NSColor *mouseoverArrowColor;
@property (strong) NSColor *highlightedControlColor;
@property (strong) NSColor *highlightedShadingColor;
@property (strong) NSColor *highlightedFrameColor;
@property (strong) NSColor *highlightedTextColor;
@property (strong) NSColor *highlightedArrowColor;
@property (strong) NSShadow *controlShadow;
@property (strong) NSShadow *textShadow;
@property (strong) NSShadow *mouseoverTextShadow;
@property (strong) NSShadow *highlightedTextShadow;
@property (strong) NSShadow *highlightedControlShadow;
@property double popUpMenuDelay;
@property NSButtonType buttonType;
@property NSBezelStyle bezelStyle;
@property AMRollOverButtonShadingMode shadingMode;


@end
