//
//  AMRollOverButtonCell.h
//  PlateControl
//
//  Created by Andreas on Sat Jan 24 2004.
//  Copyright (c) 2004 Andreas Mayer. All rights reserved.
//
//	2004-08-07	- changed superclass from NSActionCell to NSButtonCell.
//					  not sure if this makes any difference at all though ... :)
//	2005-06-02	- added shading support
//	2006-01-07	- added support for NSOnOffButton type
//	2008-04-29	- added controlShadow
//					- renamed -showArrow to -alwaysShowMenuIndicator
//	2011-08-08	- moved appearance data to AMRollOverButtonAppearance
//					- removed buttonType property, since that is part of the behaviour which should not be
//					  declared by the cell
//	2012-08-06	- replaced accessor method declarations with property declarations


#import <AppKit/AppKit.h>

@class AMRollOverButtonAppearance;

enum {
	AMRollOverButtonShadingNone = 0,
	AMRollOverButtonShadingLinear,
	AMRollOverButtonShadingBilinear
};
typedef NSUInteger AMRollOverButtonShadingMode;


@interface AMRollOverButtonCell : NSButtonCell {
	// Setting _appearance will overwrite the button's appearance.
	// Usually it's nil, indicating that the button's appearance is to be used.
	AMRollOverButtonAppearance *_appearance;
	BOOL am_bordered;
	BOOL am_mouseOver;
	// private: basic layout and geometry data
	@private
	NSBezierPath *am_backgroundPath;
	NSBezierPath *am_highlightedBackgroundPath;
	NSBezierPath *am_arrowPath;
	NSSize am_lastFrameSize;
	NSRect am_textRect;
	SEL am_getBackgroundSelector;
}

// Unless you have explicitely set the appearance of a cell instance before, using any of the appearance setters
// below will alter the appearance of all buttons(!) of the same class!

@property (strong) NSColor *controlColor;
@property (strong) NSColor *frameColor;
@property (strong) NSColor *textColor;
@property (strong) NSColor *arrowColor;
@property (strong) NSColor *shadingColor;
@property (strong) NSColor *mouseoverControlColor;
@property (strong) NSColor *mouseoverFrameColor;
@property (strong) NSColor *mouseoverTextColor;
@property (strong) NSColor *mouseoverArrowColor;
@property (strong) NSColor *mouseoverShadingColor;
@property (strong) NSColor *highlightedControlColor;
@property (strong) NSColor *highlightedFrameColor;
@property (strong) NSColor *highlightedTextColor;
@property (strong) NSColor *highlightedArrowColor;
@property (strong) NSColor *highlightedShadingColor;
@property (strong) NSShadow *controlShadow;
@property (strong) NSShadow *textShadow;
@property (strong) NSShadow *mouseoverTextShadow;
@property (strong) NSShadow *highlightedTextShadow;
@property (strong) NSShadow *highlightedControlShadow;
@property (nonatomic) NSBezelStyle bezelStyle;
@property NSBezelStyle amBezelStyle;
@property AMRollOverButtonShadingMode shadingMode;
@property double popUpMenuDelay;
@property BOOL alwaysShowMenuIndicator;

@property BOOL mouseOver;

// call this in case the form of the button changes
- (void)invalidateLayout;

- (NSSize)intrinsicContentSize;

@end


@interface AMRollOverButtonCell (Appearance)

// if not explicitely set before with -setAppearance, returns the button class' appearance
- (AMRollOverButtonAppearance *)appearance;

// only use this if you need to modify the appearance of this one cell independently of any other
- (void)setAppearance:(AMRollOverButtonAppearance *)appearance;

@end
